#ifndef NOKDE_TDELOCALE_H
#define NOKDE_TDELOCALE_H

#undef TDECORE_EXPORT
#define TDECORE_EXPORT

#undef TDE_DEPRECATED
#define TDE_DEPRECATED

#undef I18N_NOOP
#define I18N_NOOP(x) (x)
#include <tqstring.h>
inline TQString i18n(const TQString &text) { return text; }
extern TQString i18n(const TQString &index, const TQString &text);
extern TQString locate(const TQString &, const TQString &);

#endif
